mailr6558 - /1.3/sample_scripts/full_analysis.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on June 29, 2008 - 01:34:
Author: bugman
Date: Sun Jun 29 01:34:16 2008
New Revision: 6558

URL: http://svn.gna.org/viewcvs/relax?rev=6558&view=rev
Log:
The heteronucleus and proton types are now set.


Modified:
    1.3/sample_scripts/full_analysis.py

Modified: 1.3/sample_scripts/full_analysis.py
URL: 
http://svn.gna.org/viewcvs/relax/1.3/sample_scripts/full_analysis.py?rev=6558&r1=6557&r2=6558&view=diff
==============================================================================
--- 1.3/sample_scripts/full_analysis.py (original)
+++ 1.3/sample_scripts/full_analysis.py Sun Jun 29 01:34:16 2008
@@ -151,9 +151,11 @@
 # A file containing a list of spins which can be dynamically excluded at any 
point within the analysis (when set to None, this variable is not used).
 EXCLUDE = None
 
 # The bond length and CSA values.
 BOND_LENGTH = 1.02 * 1e-10
 CSA = -172 * 1e-6
+HETNUC = '15N'
+PROTON = '1H'
 
 # The grid search size (the number of increments per dimension).
 GRID_INC = 11
@@ -611,9 +613,11 @@
                 diffusion_tensor.copy('previous')
                 fix('diff')
 
-            # Set the bond length and CSA values.
+            # Set all the necessary values.
             value.set(BOND_LENGTH, 'bond_length')
             value.set(CSA, 'csa')
+            value.set(HETNUC, 'heteronucleus')
+            value.set(PROTON, 'proton')
 
             # Select the model-free model.
             model_free.select_model(model=name)
@@ -151,9 +151,11 @@
 EXCLUDE = None
 
-# The bond length and CSA values.
+# The bond length, CSA values, heteronucleus type, and proton type.
 BOND_LENGTH = 1.02 * 1e-10
 CSA = -172 * 1e-6




Related Messages


Powered by MHonArc, Updated Sun Jun 29 02:20:10 2008